package com.hungraim.ism.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ism.pojo.vo.disable.DisableExamineInfoVO;
import com.hungraim.ism.pojo.vo.disable.DisableVO;
import com.hungraim.ism.service.DisableService;
import com.hungraim.ltc.pojo.entity.disable.*;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 失能申请Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.apply/disable")
@Slf4j
public class DisableController {

    @Autowired
    private DisableService disableService;

    /**
     * 省市区
     *
     * @param districtLevel 区域级别:1省2地级市3县
     * @param districtName  上级区域代码
     */
    @RequestMapping("/district")
    public Result<List<ChFndDistrict>> district(String districtLevel, String districtName) {
        List<ChFndDistrict> districts = disableService.district(districtLevel, districtName);
        return Result.success(districts);
    }

    /**
     * 查询所有父机构
     */
    @RequestMapping("/fndOrganRoot")
    public Result<List<ChFndOrgan>> fndOrganRoot() {
        List<ChFndOrgan> organs = disableService.fndOrganRoot();
        return Result.success(organs);
    }

    /**
     * 查询所有服务方式
     */
    @RequestMapping("/fndSrvMode")
    public Result<List<ChFndSrvMode>> fndSrvMode() {
        List<ChFndSrvMode> fndSrvModes = disableService.fndSrvModeList();
        return Result.success(fndSrvModes);
    }

    /**
     * 查询机构下所有护理机构
     *
     * @param organId 机构id
     */
    @RequestMapping("/srvOrganList")
    public Result<List<ChSrvOrgan>> srvOrganList(String organId) {
        List<ChSrvOrgan> chFndSrvModes = disableService.srvOrganList(organId);
        return Result.success(chFndSrvModes);
    }

    /**
     * 失能人员信息列表
     *
     * @param organId               适用机构代码
     * @param isIncludeSubsidiaries 是否包含子机构 0包含,1不包含
     * @param districtProvincial    所在省
     * @param districtCity          所在市
     * @param districtArea          所在区域
     * @param realName              失能人员姓名
     * @param certiCode             失能人员身份证号码
     * @param dataFrom              申请来源
     * @param srvOrganId            护理机构
     * @param pageNum               当前页
     * @param pageSize              每页几条数据
     * @return 失能人员信息列表
     */
    @RequestMapping("/disableList")
    public Result<List<DisableVO>> disableList(String organId, String districtProvincial, String isIncludeSubsidiaries,
                                               String districtCity, String districtArea,
                                               String realName, String certiCode, String dataFrom,
                                               String srvOrganName, int pageNum, int pageSize) {
        IPage<DisableVO> iPage = disableService.disableList(organId, isIncludeSubsidiaries, districtProvincial,
                districtCity, districtArea, realName, certiCode, dataFrom, srvOrganName, pageNum, pageSize);
        return Result.success(iPage.getRecords());
    }

    /**
     * 失能审核信息详情
     *
     * @param applyId 申请id
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableExamineInfo")
    public Result<DisableExamineInfoVO> disableExamineInfo(String applyId) {
        DisableExamineInfoVO disableExamineInfoVO = disableService.disableExamineInfo(applyId);
        return Result.success(disableExamineInfoVO);
    }

    /**
     * 失能审核
     *
     * @param applyId     申请id
     * @param checkName   审核人
     * @param applyStatus 审核结果
     * @param checkRemark 审核备注
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableExamine")
    public Result disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark) {
        disableService.disableExamine(applyId, checkName, applyStatus, checkRemark);
        return Result.success();
    }

    /**
     * 新增失能申请
     */
    @RequestMapping("/addDisable")
    public Result addDisable(ChDisableApply chDisableApply) {
        //字段校验
        //所在省市区
        if (StringUtils.isBlank(chDisableApply.getDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getDistrictCity()) || StringUtils.isBlank(chDisableApply.getDistrictArea())) {
            return Result.failed("所在省市不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getRealName())) {
            return Result.failed("申请人姓名不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getCertiCode())) {
            return Result.failed("身份证号码不能为空!");
        }
        if (chDisableApply.getBirthday() == null) {
            return Result.failed("出生年月日不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getGender())) {
            return Result.failed("性别不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getTel())) {
            return Result.failed("手机号不能为空!");
        }
        if (chDisableApply.getRegist() == null) {
            return Result.failed("所在户籍不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAcptProvincial()) || StringUtils.isBlank(chDisableApply.getAcptCity()) || StringUtils.isBlank(chDisableApply.getAcptArea()) || StringUtils.isBlank(chDisableApply.getAcptStreet()) || StringUtils.isBlank(chDisableApply.getAcptAddress())) {
            return Result.failed("接受评定地址不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAcptSrvProvincial()) || StringUtils.isBlank(chDisableApply.getAcptSrvCity()) || StringUtils.isBlank(chDisableApply.getAcptSrvArea()) || StringUtils.isBlank(chDisableApply.getAcptSrvStreet()) || StringUtils.isBlank(chDisableApply.getAcptSrvAddress())) {
            return Result.failed("接受服务地址不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAdressDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCity()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCode()) || StringUtils.isBlank(chDisableApply.getAddressRoadDetail()) || StringUtils.isBlank(chDisableApply.getAddressNumberDetail())) {
            return Result.failed("现住址不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getDisease())) {
            return Result.failed("诊断疾病不能为空!");
        }
        if (chDisableApply.getSrvModeId() == null) {
            return Result.failed("申请服务方式不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getDiseaseDesc())) {
            return Result.failed("疾病描述及诊断不能为空!");
        }
        if (chDisableApply.getMedicalType() == null) {
            return Result.failed("医保类型不能为空!");
        }
        disableService.addDisable(chDisableApply);
        return Result.success();
    }

}
