package com.hungraim.ism.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ism.dao.*;
import com.hungraim.ism.pojo.vo.disable.DisableExamineInfoVO;
import com.hungraim.ism.pojo.vo.disable.DisableVO;
import com.hungraim.ism.pojo.vo.disable.ExamineRecord;
import com.hungraim.ism.service.DisableService;
import com.hungraim.ltc.pojo.entity.disable.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class DisableServiceImpl implements DisableService {

    @Autowired
    private DisableApplyMapper disableApplyMapper;
    @Autowired
    private FndDistrictMapper districtMapper;
    @Autowired
    private FndOrganMapper fndOrganMapper;
    @Autowired
    private FndStreetMapper fndStreetMapper;
    @Autowired
    private FndSrvModeMapper fndSrvModeMapper;
    @Autowired
    private SrvOrganMapper srvOrganMapper;

    /**
     * 获取机构ids
     *
     * @param organId  父机构id
     * @param organIds 机构list
     */
    private void getOrganList(String organId, List<String> organIds) {
        QueryWrapper<ChFndOrgan> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("STATUS", "1");
        queryWrapper.eq("PARENT_ID", organId);
        List<ChFndOrgan> organs = fndOrganMapper.selectList(queryWrapper);
        if (organs != null && organs.size() != 0) {
            for (ChFndOrgan chFndOrgan : organs) {
                String childOrganId = chFndOrgan.getOrganId();
                organIds.add(childOrganId);
                if ("1".equals(chFndOrgan.getIsLeaf())) {
                    getOrganList(childOrganId, organIds);
                }
            }
        }
    }


    @Override
    public Page<DisableVO> disableList(String organId, String isIncludeSubsidiaries, String districtProvincial, String districtCity,
                                       String districtArea, String realName, String certiCode, String dataFrom,
                                       String srvOrganName, int page, int pageSize) {
        // 没有organId参数的时候，这个集合就为null
        List<String> organIds = null;
        if (StrUtil.isNotBlank(organId)) {
            organIds = new ArrayList<>();
            // 先把最顶层id添加到集合
            organIds.add(organId);
            // 获取子孙机构集合
            if ("0".equals(isIncludeSubsidiaries)) {
                this.getOrganList(organId, organIds);
            }
        }
        return disableApplyMapper.disableList(new Page<>(page, pageSize), organIds, isIncludeSubsidiaries, districtProvincial,
                districtCity, districtArea, realName, certiCode, dataFrom, srvOrganName);
    }

    @Override
    public DisableExamineInfoVO disableExamineInfo(String applyId) {
        DisableExamineInfoVO disableExamineInfoVO = disableApplyMapper.selectDisableExamineInfoByApplyId(applyId);
        List<ExamineRecord> examineRecords = disableApplyMapper.listExamineRecordByApplyId(applyId);
        disableExamineInfoVO.setExamineRecords(examineRecords);
        return disableExamineInfoVO;
    }

    @Override
    public void addDisable(ChDisableApply chDisableApply) {
        disableApplyMapper.insert(chDisableApply);
    }

    @Override
    public void disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark) {
        ChDisableApply chDisableApply = disableApplyMapper.selectById(applyId);
        chDisableApply.setCheckName(checkName);
        chDisableApply.setApplyStatus(applyStatus);
        chDisableApply.setCheckRemark(checkRemark);
    }

    @Override
    public List<ChFndDistrict> district(String districtLevel, String districtName) {
        if ("4".equals(districtLevel)) {
            QueryWrapper<ChFndStreet> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("STREET_NAME", districtName);
            queryWrapper.eq("IS_VALID", 0);
            List<ChFndStreet> fndStreets = fndStreetMapper.selectList(queryWrapper);
            List<ChFndDistrict> resuts = new ArrayList<>();
            for (ChFndStreet chFndStreet : fndStreets) {
                ChFndDistrict chFndDistrict = new ChFndDistrict();
                chFndDistrict.setDistrictCode(chFndStreet.getStreetCode());
                chFndDistrict.setDistrictName(chFndStreet.getStreetName());
                chFndDistrict.setParentDistirctCode(chFndStreet.getAreaCode());
            }
            return resuts;
        } else {
            QueryWrapper<ChFndDistrict> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("IS_VALID", "Y");
            queryWrapper.eq("DISTRICT_LEVEL", districtLevel);
            if (!"1".equals(districtLevel)) {
                queryWrapper.eq("DISTRICT_NAME", districtName);
            }
            return districtMapper.selectList(queryWrapper);
        }
    }

    @Override
    public List<ChFndOrgan> fndOrganRoot() {
        QueryWrapper<ChFndOrgan> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("IS_LEAF", "1");
        queryWrapper.and(wrapper -> wrapper.isNull("PARENT_ID").or().eq("PARENT_ID", ""));
        return fndOrganMapper.selectList(queryWrapper);
    }

    @Override
    public List<ChFndSrvMode> fndSrvModeList() {
        return fndSrvModeMapper.selectList(new QueryWrapper<>());
    }

    @Override
    public List<ChSrvOrgan> srvOrganList(String organId) {
        return srvOrganMapper.selectList(new QueryWrapper<ChSrvOrgan>().eq("organ_id", organId));
    }

}